# Generated by Django 4.2.16 on 2024-12-02 22:28

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('djautotask', '0123_alter_project_account_alter_task_project_and_more'),
    ]

    operations = [
        migrations.AddField(
            model_name='project',
            name='create_date_time',
            field=models.DateTimeField(null=True),
        ),
    ]



# Generated by Django 4.2.16 on 2024-12-02 20:53

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('djautotask', '0122_alter_ticketnote_title'),
    ]

    operations = [
        migrations.AlterField(
            model_name='project',
            name='account',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='account_projects', to='djautotask.account'),
        ),
        migrations.AlterField(
            model_name='task',
            name='project',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='project_tasks', to='djautotask.project'),
        ),
        migrations.AlterField(
            model_name='ticket',
            name='account',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='account_tickets', to='djautotask.account'),
        ),
    ]



# Generated by Django 4.2.16 on 2024-12-10 11:53

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('djautotask', '0124_project_create_date_time'),
    ]

    operations = [
        migrations.AlterField(
            model_name='project',
            name='account',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, to='djautotask.account'),
        ),
        migrations.AlterField(
            model_name='task',
            name='project',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='djautotask.project'),
        ),
        migrations.AlterField(
            model_name='ticket',
            name='account',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to='djautotask.account'),
        ),
    ]



# Generated by Django 4.2.16 on 2024-11-04 15:28

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('djautotask', '0120_merge_20241101_1316'),
        ('djautotask', '0120_resource_title'),
    ]

    operations = [
    ]



# Generated by Django 4.2.16 on 2024-10-30 15:21

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('djautotask', '0119_merge_20241024_1521'),
    ]

    operations = [
        migrations.AddField(
            model_name='resource',
            name='title',
            field=models.CharField(blank=True, max_length=250, null=True),
        ),
    ]
